@@ -333,10 +333,11 @@ ges_timeout_add (guint interval, GSourceFunc func, gpointer udata,
 
   g_source_set_callback (source, func, udata, notify);
   g_source_attach (source, context);
+  g_source_unref (source);
 }
 
 void
-ges_idle_add (GSourceFunc func, gpointer udata, GDestroyNotify notify)
+ges_callback_add (GSourceFunc func, gpointer udata, GDestroyNotify notify)
 {
   GMainContext *context = g_main_context_get_thread_default ();
   GSource *source = g_idle_source_new ();
@@ -344,8 +345,9 @@ ges_idle_add (GSourceFunc func, gpointer udata, GDestroyNotify notify)
     context = g_main_context_default ();
 
   g_source_set_callback (source, func, udata, notify);
+  g_source_set_priority (source, G_PRIORITY_DEFAULT);
   g_source_attach (source, context);
-
+  g_source_unref (source);
 }
 
 gboolean
